from typing import Literal

YesNoDefault = Literal["yes", "no", "default"]
YesNoDefaultRequired = Literal["yes", "no", "default", "required"]
PPPService = Literal["any", "async", "l2tp", "ovpn", "pppoe", "pptp", "sstp"]
